@@ -83,7 +83,7 @@ Arch::~Arch()
 }
 
 //Check if a compress utility exists
-void Arch::verifyCompressUtilityIsAvailable(const QString &utility)
+void Arch::verifyCompressUtilityIsAvailable( const QString &utility )
 {
   // see if the utility is in the PATH of the user.
   QString cmd = KGlobal::dirs()->findExe( utility );
@@ -91,7 +91,7 @@ void Arch::verifyCompressUtilityIsAvailable(const QString &utility)
 }
 
 //Check if a utility can uncompress files
-void Arch::verifyUncompressUtilityIsAvailable(const QString &utility)
+void Arch::verifyUncompressUtilityIsAvailable( const QString &utility )
 {
   // see if the utility is in the PATH of the user.
   QString cmd = KGlobal::dirs()->findExe( utility );
@@ -133,8 +133,9 @@ void Arch::slotDeleteExited( KProcess *_kp )
 
     if ( !getLastShellOutput().isNull() )
     {
-      msg += i18n( "\nUse \"Details\" to view the last shell output." );
-      KMessageBox::detailedError( m_gui, msg, getLastShellOutput() );
+      QStringList list = QStringList::split( "\n", getLastShellOutput() );
+      KMessageBox::errorList( m_gui, msg, list );
+      clearShellOutput();
     }
     else
     {
@@ -180,8 +181,10 @@ void Arch::slotExtractExited( KProcess *_kp )
 
         if ( !getLastShellOutput().isNull() )
         {
-            msg += i18n( "\nUse \"Details\" to view the last shell output." );
-            KMessageBox::detailedError( m_gui, msg, getLastShellOutput() );
+            //getLastShellOutput() is a QString. errorList is expecting QStringLists to show in multiple lines
+            QStringList list = QStringList::split( "\n", getLastShellOutput() );
+            KMessageBox::errorList( m_gui, msg, list );
+            clearShellOutput();
         }
         else
         {
@@ -216,8 +219,9 @@ void Arch::slotAddExited( KProcess *_kp )
 
     if ( !getLastShellOutput().isNull() )
     {
-      msg += i18n( "\nUse \"Details\" to view the last shell output." );
-      KMessageBox::detailedError( m_gui, msg, getLastShellOutput() );
+      QStringList list = QStringList::split( "\n", getLastShellOutput() );
+      KMessageBox::errorList( m_gui, msg, list );
+      clearShellOutput();
     }
     else
     {
