@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: arkutils.h,v 1.6 2003/11/06 00:02:30 pinto Exp $
+ $Id: arkutils.h 490596 2005-12-22 13:05:45Z scripty $
 
  ark -- archiver for the KDE project
 
@@ -25,7 +25,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -34,6 +34,8 @@
 
 #include <qstring.h>
 
+#include <kio/global.h>
+
 class QStringList;
 
 // various functions for massaging timestamps
@@ -47,8 +49,8 @@ namespace ArkUtils
                        const QString &day,
                        const QString &year);
   bool haveDirPermissions(const QString &strFile);
-  bool diskHasSpace(const QString &dir, long size);
-  long getSizes(QStringList *list);
+  bool diskHasSpace(const QString &dir, KIO::filesize_t size);
+  KIO::filesize_t getSizes(QStringList *list);
 }
 
 #endif
