@@ -68,10 +68,17 @@ QString FileLVI::key( int column, bool ascending ) const
 
 int FileLVI::compare( QListViewItem * i, int column, bool ascending ) const
 {
+	FileLVI * item = static_cast< FileLVI * >( i );
+
+	if ( ( this->childCount() > 0 ) && ( item->childCount() == 0 ) )
+		return -1;
+	
+	if ( ( this->childCount() == 0 ) && ( item->childCount() > 0 ) )
+		return 1;
+
 	if ( column == 0 )
 		return KListViewItem::compare( i, column, ascending );
-
-	FileLVI * item = static_cast< FileLVI * >( i );
+	
 	columnName colName = ( static_cast< FileListView * > ( listView() ) )->nameOfColumn( column );
 	switch ( colName )
 	{
@@ -190,7 +197,7 @@ FileListView::FileListView(QWidget *parent, const char* name)
 	setItemsMovable( false );
 	setRootIsDecorated( true );
 	setShowSortIndicator( true );
-	setResizeMode( QListView::AllColumns );
+	setItemMargin( 3 );
 	header()->hide(); // Don't show the header until there is something to be shown in it
 
 	m_pressed = false;
@@ -248,9 +255,10 @@ QStringList FileListView::selectedFilenames()
 	{
 		if ( item->isSelected() )
 		{
-			// If the item has children, add each child instead of the item
+			// If the item has children, add each child and the item
 			if ( item->childCount() > 0 )
 			{
+				files += item->fileName();
 				files += childrenOf( item );
 
 				/* If we got here, then the logic for "going to the next item"
@@ -263,7 +271,8 @@ QStringList FileListView::selectedFilenames()
 				while ( !nitem && item->parent() )
 				{
 					item = static_cast<FileLVI*>( item->parent() );
-					nitem = static_cast<FileLVI*>( item->parent()->nextSibling() );
+					if ( item->parent() )
+						nitem = static_cast<FileLVI*>( item->parent()->nextSibling() );
 				}
 				item = nitem;
 				continue;
@@ -408,6 +417,8 @@ void FileListView::setHeaders( const ColumnList& columns )
 		int colnum = addColumn( pair.first );
 		setColumnAlignment( colnum, pair.second );
 	}
+	
+	setResizeMode( QListView::LastColumn );
 
 	header()->show();
 }
@@ -552,6 +563,7 @@ QStringList FileListView::childrenOf( FileLVI* parent )
 		}
 		else
 		{
+			children += item->fileName();
 			children += childrenOf( item );
 		}
 		item = static_cast<FileLVI*>( item->nextSibling() );
