@@ -1,8 +1,5 @@
-//  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: zoo.h,v 1.12 2004/05/31 20:31:43 bmeyer Exp $
-
  ark -- archiver for the KDE project
 
  Copyright (C)
@@ -22,43 +19,41 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#ifndef __ZOO_H__
-#define __ZOO_H__ 
+#ifndef ZOO_H
+#define ZOO_H 
+
+#include "arch.h"
 
 class QString;
 class QCString;
 class QStringList;
 
-class Arch;
 class ArkWidget;
 
 class ZooArch : public Arch
 {
   Q_OBJECT
-public:
-  ZooArch( ArkWidget *_gui,
-	   const QString & _fileName );
-  virtual ~ZooArch() { }
-	
-  virtual void open();
-  virtual void create();
-	
-  virtual void addFile( QStringList* );
-  virtual void addDir(const QString & _dirName);
+  public:
+    ZooArch( ArkWidget *, const QString & );
+    virtual ~ZooArch() { }
 
-  virtual void remove(QStringList *);
-  virtual void unarchFile(QStringList *, const QString & _destDir="",
-			  bool viewFriendly=false);
+    virtual void open();
+    virtual void create();
 
-protected slots:
-  virtual bool processLine(const QCString &line);
-	
-private:
-  void initExtract( bool, bool, bool );
-  void setHeaders();
+    virtual void addFile( const QStringList & );
+    virtual void addDir( const QString & );
+
+    virtual void remove( QStringList * );
+    virtual void unarchFileInternal();
+
+  protected slots:
+    virtual bool processLine( const QCString &line );
+
+  private:
+    void setHeaders();
 };
 
-#endif /*  __ZOO_H__ */
+#endif //ZOO_H
