@@ -21,6 +21,7 @@
 #include <qlayout.h>
 #include <qtabwidget.h>
 #include <qlabel.h>
+#include <qtoolbutton.h>
 #include <qfile.h>
 #include <kconfig.h>
 #include <kdeversion.h>
@@ -48,6 +49,7 @@
 
 #include "kgpgoptions.h"
 #include "kgpgsettings.h"
+#include "listkeys.h"
 
 #include "conf_decryption.h"
 #include "conf_encryption.h"
@@ -63,14 +65,14 @@ class QTabWidget;
 kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
  : KConfigDialog( parent, name, KGpgSettings::self())
 {
-	ks=new KSimpleConfig ("kgpgrc");
-
 	defaultServerList="hkp://wwwkeys.eu.pgp.net ";
 	defaultServerList+=i18n("(Default)");
 	defaultServerList+=",hkp://search.keyserver.net,hkp://wwwkeys.pgp.net,hkp://pgp.dtype.org,hkp://wwwkeys.us.pgp.net";
-	ks->setGroup("Servers");
-	serverList=QStringList::split (",",ks->readEntry("Server_List",defaultServerList));
+	config = new KConfig ("kgpgrc");
+	config->setGroup("Servers");
+	serverList=QStringList::split (",",config->readEntry("Server_List",defaultServerList));
 	keyServer = KgpgInterface::getGpgSetting("keyserver", KGpgSettings::gpgConfigPath());
+
 	if (!keyServer.isEmpty()) serverList.prepend(keyServer+" "+i18n("(Default)"));
 	
 	defaultHomePath=QDir::homeDirPath()+"/.gnupg/";
@@ -102,23 +104,32 @@ kdDebug(2100)<<"Adding pages"<<endl;
         addPage(page4, i18n("GnuPG Settings"), "kgpg");
 	addPage(page6, i18n("Key Servers"), "network");
 	addPage(page7, i18n("Misc"), "misc");
-	
-	
 
+	page1->clear_akey->setIconSet(QIconSet(QPixmap(SmallIcon("clear_left"))));
+	page1->clear_fkey->setIconSet(QIconSet(QPixmap(SmallIcon("clear_left"))));
+	
         // The following widgets are managed manually.
-        connect(page1->encrypt_to_always, SIGNAL(toggled(bool)), this, SLOT(updateButtons()));
-        connect(page1->file_key, SIGNAL(activated(int)), this, SLOT(updateButtons()));
-        connect(page1->always_key, SIGNAL(activated(int)), this, SLOT(updateButtons()));
+        connect(page1->change_fkey, SIGNAL(clicked()), this, SLOT(insertFileKey()));
+	connect(page1->clear_fkey, SIGNAL(clicked()), page1->kcfg_FileKey, SLOT(clear()));
+	connect(page1->change_akey, SIGNAL(clicked()), this, SLOT(insertAlwaysKey()));
+	connect(page1->clear_akey, SIGNAL(clicked()), page1->alwaysKey, SLOT(clear()));
+	connect(page1->alwaysKey, SIGNAL(textChanged(const QString&)), this, SLOT(updateButtons()));
 	connect(page4->gpg_conf_path, SIGNAL(textChanged(const QString&)), this, SLOT(updateButtons()));
 	connect(page4->gpg_home_path, SIGNAL(textChanged(const QString&)), this, SLOT(updateButtons()));
         connect(page4->use_agent, SIGNAL(toggled(bool)), this, SLOT(updateButtons()));
 	connect(page4->changeHome, SIGNAL(clicked()), this, SLOT(slotChangeHome()));
+	connect(page4->kcfg_PubKeyring, SIGNAL(toggled (bool)), page4->kcfg_PubKeyringUrl, SLOT(setEnabled(bool)));
+	connect(page4->kcfg_PubKeyring, SIGNAL(toggled (bool)), this, SLOT(checkAdditionalState(bool)));
+	connect(page4->kcfg_PrivKeyring, SIGNAL(toggled (bool)), page4->kcfg_PrivKeyringUrl, SLOT(setEnabled(bool)));
+	connect(page4->kcfg_PrivKeyring, SIGNAL(toggled (bool)), this, SLOT(checkAdditionalState(bool)));
 	connect(page6->server_add, SIGNAL(clicked()), this, SLOT(slotAddKeyServer()));
 	connect(page6->server_del, SIGNAL(clicked()), this, SLOT(slotDelKeyServer()));
 	connect(page6->server_default, SIGNAL(clicked()), this, SLOT(slotDefaultKeyServer()));
 	connect(page6->ServerBox, SIGNAL(currentChanged ( QListBoxItem *)), this, SLOT(updateButtons()));
 	connect(page7->pushShredder, SIGNAL(clicked ()), this, SIGNAL(installShredder()));
 
+	//connect(this, SIGNAL(settingsChanged()), SLOT(updateSettings()));
+
 	keyGood=KGpgSettings::colorGood();
 	keyUnknown=KGpgSettings::colorUnknown();
 	keyRev=KGpgSettings::colorRev();
@@ -127,7 +138,50 @@ kdDebug(2100)<<"Adding pages"<<endl;
 
 
 kgpgOptions::~kgpgOptions()
-{}
+{
+delete config;
+}
+
+
+void kgpgOptions::checkAdditionalState(bool)
+{
+// enable / disable the "use only this keyring" option depending on the other checkboxes state
+
+if (page4->kcfg_PubKeyring->isOn() && page4->kcfg_PrivKeyring->isOn())
+page4->kcfg_OnlyAdditional->setEnabled(true);
+else
+page4->kcfg_OnlyAdditional->setEnabled(false);
+}
+
+void kgpgOptions::insertFileKey()
+{
+		QString signKeyID;
+		///// open key selection dialog
+                KgpgSelKey *opts=new KgpgSelKey(this,0,true,page1->kcfg_FileKey->text());
+
+                if (opts->exec()==QDialog::Accepted) {
+                        page1->kcfg_FileKey->setText(opts->getkeyID());
+                } else {
+                        delete opts;
+                        return;
+                }
+                delete opts;
+}
+
+void kgpgOptions::insertAlwaysKey()
+{
+		QString signKeyID;
+		///// open key selection dialog
+                KgpgSelKey *opts=new KgpgSelKey(this,0,true,page1->alwaysKey->text());
+
+                if (opts->exec()==QDialog::Accepted) {
+                        page1->alwaysKey->setText(opts->getkeyID());
+                } else {
+                        delete opts;
+                        return;
+                }
+                delete opts;
+}
 
 void kgpgOptions::slotChangeHome()
 {
@@ -166,40 +220,46 @@ if (!gpgHome.endsWith("/")) gpgHome.append("/");
 
 void kgpgOptions::updateWidgets()
 {
+QString pubKeyring,privKeyring;
 
-        alwaysKeyID=KgpgInterface::getGpgSetting("encrypt-to", KGpgSettings::gpgConfigPath());
-
-        encryptToAlways = !alwaysKeyID.isEmpty();
-        defaultEncryptToAlways = false;
-       
-        page1->encrypt_to_always->setChecked(encryptToAlways);
-
-        listkey();
-        fileEncryptionKey = KGpgSettings::fileEncryptionKey();
-        if (!fileEncryptionKey.isEmpty()) {
-                page1->file_key->setCurrentItem(fileEncryptionKey);
-        }
-
-        if (!alwaysKeyName.isEmpty()) {
-                page1->always_key->setCurrentItem(alwaysKeyName);
-        }
-        
         gpgConfigPath = KGpgSettings::gpgConfigPath();
 	page4->gpg_conf_path->setText(KURL(gpgConfigPath).fileName());
 	page4->gpg_home_path->setText(KURL(gpgConfigPath).directory(false));
+	
+	pubKeyring=KgpgInterface::getGpgSetting("keyring", gpgConfigPath);
+	if (pubKeyring!="")
+	{
+	page4->kcfg_PubKeyringUrl->setURL(pubKeyring);
+	page4->kcfg_PubKeyring->setChecked(true);
+	}
+	else page4->kcfg_PubKeyring->setChecked(false);
 
-        useAgent = KgpgInterface::getGpgBoolSetting("use-agent", KGpgSettings::gpgConfigPath());
+	privKeyring=KgpgInterface::getGpgSetting("secret-keyring", gpgConfigPath);
+	if (privKeyring!="")
+	{
+	page4->kcfg_PrivKeyringUrl->setURL(privKeyring);
+	page4->kcfg_PrivKeyring->setChecked(true);
+	}
+	else page4->kcfg_PrivKeyring->setChecked(false);
+
+	page4->kcfg_OnlyAdditional->setChecked(KgpgInterface::getGpgBoolSetting("no-default-keyring", gpgConfigPath));
+
+	// fill some values from kgpg's config file
+
+        useAgent = KgpgInterface::getGpgBoolSetting("use-agent", gpgConfigPath);
         defaultUseAgent = false;
 
+        page1->alwaysKey->setText(KgpgInterface::getGpgMultiSetting("encrypt-to", gpgConfigPath));
+	alwaysKeyID = page1->alwaysKey->text();
+
         page4->use_agent->setChecked( useAgent );
 
-        keyServer = KgpgInterface::getGpgSetting("keyserver", KGpgSettings::gpgConfigPath());
+        keyServer = KgpgInterface::getGpgSetting("keyserver", gpgConfigPath);
         defaultKeyServer = "hkp://wwwkeys.pgp.net";
-        
+
         if (keyServer.isEmpty())
 		keyServer = defaultKeyServer;
 
-	
 	page6->ServerBox->clear();
 	page6->ServerBox->insertStringList(serverList);
 	
@@ -209,12 +269,21 @@ void kgpgOptions::updateWidgets()
 
 void kgpgOptions::updateWidgetsDefault()
 {
-        page1->encrypt_to_always->setChecked( defaultEncryptToAlways );
+
+	page1->alwaysKey->clear();
+	page1->kcfg_FileKey->clear();
 
         page4->use_agent->setChecked( defaultUseAgent );	
 	
 	page4->gpg_conf_path->setText(defaultConfigPath);
 	page4->gpg_home_path->setText(defaultHomePath);
+
+	page4->kcfg_PubKeyringUrl->setURL(QString::null);
+	page4->kcfg_PubKeyring->setChecked(false);
+	page4->kcfg_PrivKeyringUrl->setURL(QString::null);
+	page4->kcfg_PrivKeyring->setChecked(false);
+	page4->kcfg_OnlyAdditional->setChecked(false);
+
 	
 	page6->ServerBox->clear();
 	page6->ServerBox->insertStringList(QStringList::split(",",defaultServerList));
@@ -224,7 +293,7 @@ void kgpgOptions::updateWidgetsDefault()
 
 bool kgpgOptions::isDefault()
 {
-	if (page1->encrypt_to_always->isChecked() != defaultEncryptToAlways)
+	if (!page1->alwaysKey->text().isEmpty())
 		return false;
 
         if (page4->gpg_conf_path->text()!=defaultConfigPath)
@@ -247,15 +316,8 @@ bool kgpgOptions::isDefault()
 
 bool kgpgOptions::hasChanged()
 {
-	if (page1->kcfg_EncryptFilesTo->isChecked() &&
-	    (page1->file_key->currentText() != fileEncryptionKey))
-		return true;
 
-	if (page1->encrypt_to_always->isChecked() != encryptToAlways)
-		return true;
-
-	if (page1->encrypt_to_always->isChecked() &&
-	    (page1->always_key->currentText().section(':',0,0) != alwaysKeyID))
+	if (page1->alwaysKey->text()!= alwaysKeyID)
 		return true;
 
 	if (page4->gpg_conf_path->text() != KURL(gpgConfigPath).fileName())
@@ -268,9 +330,9 @@ bool kgpgOptions::hasChanged()
 		
 	QStringList currList;
 	for (uint i=0;i<page6->ServerBox->count();i++)
-	currList.append(page6->ServerBox->text(i));
-	
+	currList.append(page6->ServerBox->text(i));	
 	if (currList!=serverList) return true;
+
 	return false;
 }
 
@@ -279,34 +341,42 @@ void kgpgOptions::updateSettings()
         // Update config path first!
 	
 	KGpgSettings::setGpgConfigPath( page4->gpg_home_path->text()+page4->gpg_conf_path->text() );
+	KGpgSettings::writeConfig();	//Don't forget to write the config file
 	if (page4->gpg_home_path->text()!=KURL(gpgConfigPath).directory(false))
 	{
-
 	if (page4->gpg_home_path->text()!=defaultHomePath)
 	setenv("GNUPGHOME",page4->gpg_home_path->text().ascii(),1);
 	else setenv("GNUPGHOME","",1);
 	emit homeChanged();
 	gpgConfigPath = KGpgSettings::gpgConfigPath();
 	}
-	
-        ////////////  save selected keys for file encryption & always encrypt with
-        if (page1->kcfg_EncryptFilesTo->isChecked())
-		fileEncryptionKey = page1->file_key->currentText();
+
+	bool emitReload=false;
+
+	if (page4->kcfg_OnlyAdditional->isChecked()!=KgpgInterface::getGpgBoolSetting("no-default-keyring", gpgConfigPath)) emitReload=true;
+	KgpgInterface::setGpgBoolSetting("no-default-keyring",page4->kcfg_OnlyAdditional->isChecked(), gpgConfigPath);
+
+	if (page4->kcfg_PubKeyring->isChecked())
+	{
+	if (page4->kcfg_PubKeyringUrl->url()!=KgpgInterface::getGpgSetting("keyring", gpgConfigPath)) emitReload=true;
+	KgpgInterface::setGpgSetting("keyring",page4->kcfg_PubKeyringUrl->url(), gpgConfigPath);
+	}
+	else 
+	{
+	if (KgpgInterface::getGpgSetting("keyring", gpgConfigPath)!="") emitReload=true;
+	KgpgInterface::setGpgSetting("keyring",QString::null, gpgConfigPath);
+	}
+
+	if (page4->kcfg_PrivKeyring->isChecked())
+	{
+	if (page4->kcfg_PrivKeyringUrl->url()!=KgpgInterface::getGpgSetting("secret-keyring", gpgConfigPath)) emitReload=true;
+	KgpgInterface::setGpgSetting("secret-keyring",page4->kcfg_PrivKeyringUrl->url(), gpgConfigPath);
+	}
 	else
-		fileEncryptionKey = QString::null;
-	if (fileEncryptionKey!=KGpgSettings::fileEncryptionKey())
-        KGpgSettings::setFileEncryptionKey( fileEncryptionKey );
-
-	encryptToAlways = page1->encrypt_to_always->isChecked();
-
-        if (encryptToAlways)
-        	alwaysKeyID = page1->always_key->currentText().section(':',0,0);
-        else
-        	alwaysKeyID = QString::null;
-	KgpgInterface::setGpgSetting("encrypt-to",alwaysKeyID, KGpgSettings::gpgConfigPath());
-	
-	//////////////////  save key servers
-	
+	{
+	if (KgpgInterface::getGpgSetting("secret-keyring", gpgConfigPath)!="") emitReload=true;
+	KgpgInterface::setGpgSetting("secret-keyring",QString::null, gpgConfigPath);
+	}
 
 	emit changeFont(kfc->font());
         ///////////////  install service menus
@@ -322,6 +392,8 @@ void kgpgOptions::updateSettings()
         else
                 slotRemoveMenu("decryptfile.desktop");
 
+	KgpgInterface::setGpgMultiSetting("encrypt-to",QStringList::split(" ",page1->alwaysKey->text()),KGpgSettings::gpgConfigPath());
+	alwaysKeyID = page1->alwaysKey->text();
 	
         useAgent = page4->use_agent->isChecked();
 
@@ -336,6 +408,9 @@ void kgpgOptions::updateSettings()
 		KgpgInterface::setGpgBoolSetting("use-agent",false, KGpgSettings::gpgConfigPath());
 	}
 	
+	//////////////////  save key servers
+
+
 	QString currList;
 	serverList=QStringList ();
 	for (uint i=0;i<page6->ServerBox->count();i++)
@@ -348,21 +423,23 @@ void kgpgOptions::updateSettings()
 	serverList.append(currItem);
 	}
 	}
-	currList=serverList.join(",");
-	ks->setGroup("Servers");
-	ks->writeEntry("Server_List",currList);
+
 	KgpgInterface::setGpgSetting("keyserver",keyServer, KGpgSettings::gpgConfigPath());
 	serverList.prepend(keyServer+" "+i18n("(Default)"));
-	
+	currList=serverList.join(",");
+
 	if (keyGood!=page3->kcfg_ColorGood->color()) 
 	emit refreshTrust(GoodColor,page3->kcfg_ColorGood->color());
 	if (keyBad!=page3->kcfg_ColorBad->color()) emit refreshTrust(BadColor,page3->kcfg_ColorBad->color());
 	if (keyUnknown!=page3->kcfg_ColorUnknown->color()) emit refreshTrust(UnknownColor,page3->kcfg_ColorUnknown->color());
 	if (keyRev!=page3->kcfg_ColorRev->color()) emit refreshTrust(RevColor,page3->kcfg_ColorRev->color());
 
-	KGpgSettings::writeConfig();
-	ks->sync();
+
+//	KGpgSettings::writeConfig();
+	config->setGroup("Servers");
+	config->writeEntry("Server_List",currList);
 	emit settingsUpdated();
+	if (emitReload) emit reloadKeyList();
 }
 
 
@@ -471,13 +548,13 @@ void kgpgOptions::listkey()
                                         alwaysKeyName=tst.section(':',4,4).right(8)+":"+name;
 				if (issec.find(tst.section(':',4,4).right(8),0,FALSE)!=-1)
 				{
-				page1->file_key->insertItem(pixkeyDouble,tst.section(':',4,4).right(8)+":"+name);
-                                page1->always_key->insertItem(pixkeyDouble,tst.section(':',4,4).right(8)+":"+name);
+//***                           page1->file_key->insertItem(pixkeyDouble,tst.section(':',4,4).right(8)+":"+name);
+//***                           page1->always_key->insertItem(pixkeyDouble,tst.section(':',4,4).right(8)+":"+name);
 				}
 				else
 				{
-                                page1->file_key->insertItem(pixkeySingle,tst.section(':',4,4).right(8)+":"+name);
-                                page1->always_key->insertItem(pixkeySingle,tst.section(':',4,4).right(8)+":"+name);
+//***                           page1->file_key->insertItem(pixkeySingle,tst.section(':',4,4).right(8)+":"+name);
+//***                           page1->always_key->insertItem(pixkeySingle,tst.section(':',4,4).right(8)+":"+name);
 				}
                         }
                 }
@@ -485,8 +562,8 @@ void kgpgOptions::listkey()
         pclose(fp);
         if (counter==0) {
                 ids+="0";
-                page1->file_key->insertItem(i18n("none"));
-                page1->always_key->insertItem(i18n("none"));
+//***                           page1->file_key->insertItem(i18n("none"));
+//***                           page1->always_key->insertItem(i18n("none"));
         }
 }
 
