@@ -15,8 +15,8 @@
  ***************************************************************************/
 
 
-#ifndef KVALUECOLTEXTEXPORT_H
-#define KVALUECOLTEXTEXPORT_H
+#ifndef KHE_KVALUECOLTEXTEXPORT_H
+#define KHE_KVALUECOLTEXTEXPORT_H
 
 #include "kbytecodec.h"
 #include "kbuffercoltextexport.h"
@@ -31,16 +31,15 @@ class KValueColumn;
 class KValueColTextExport : public KBufferColTextExport
 {
   public:
-    KValueColTextExport( const KValueColumn* BF, char *D, KCoordRange CR );
+    KValueColTextExport( const KValueColumn* BF, const char *D, KCoordRange CR );
     virtual ~KValueColTextExport();
 
   protected:
-    virtual void print( char **T ) const;
+    virtual void print( QString &T ) const;
 
 
   protected:
-    int CodingWidth;
-    KByteCodec::coding CodingFunction;
+    KByteCodec *ByteCodec;
 };
 
 }
