@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -33,7 +33,10 @@ class QWidget;
 class KConfig;
 class KURLRequester;
 class QCheckBox;
+class QRadioButton;
 class QSpinBox;
+class QSlider;
+class KComboBox;
 
 class WarningConfig : public KCModule
 {
@@ -49,6 +52,13 @@ public:
 
 private slots:
   void configChanged();
+  void brightness_changed(bool v);
+  void throttle_changed(bool v);
+  void performance_changed(bool v);
+  void checkLowTimeChanged(bool state);
+  void checkLowPercentChanged(bool state);
+  void checkCriticalTimeChanged(bool state);
+  void checkCriticalPercentChanged(bool state);
     
 private:
   void my_load(int x);
@@ -57,21 +67,38 @@ private:
  
   KURLRequester* editRunCommand;
   KURLRequester* editPlaySound;
-  QSpinBox* editLow;
+  QCheckBox* checkLowTime;
+  QCheckBox* checkLowPercent;
+  QCheckBox* checkCriticalTime;
+  QCheckBox* checkCriticalPercent;
+  QSpinBox* editLowTime;
+  QSpinBox* editLowPercent;
+  QSpinBox* editCriticalTime;
+  QSpinBox* editCriticalPercent;
  
   QCheckBox *checkRunCommand;
   QCheckBox *checkPlaySound;
   QCheckBox *checkBeep;
   QCheckBox *checkNotify;
-  QCheckBox *checkSuspend;
-  QCheckBox *checkStandby;
-  QCheckBox *checkHibernate;
+  QCheckBox *checkBrightness;
+  QSlider   *valueBrightness;
+  QCheckBox *performance, *throttle;
+  KComboBox *performance_val, *throttle_val;
+  QRadioButton *checkNone;
+  QRadioButton *checkShutdown;
+  QRadioButton *checkLogout;
+  QRadioButton *checkSuspend;
+  QRadioButton *checkStandby;
+  QRadioButton *checkHibernate;
  
-  bool    apm, runcommand, playsound, beep, notify, do_suspend, do_standby, do_hibernate;
+  bool    apm, runcommand, playsound, beep, notify, do_suspend, do_standby, do_hibernate, logout, shutdown, do_brightness;
+  bool	  do_performance, do_throttle;
+  bool    time_based_action_low, time_based_action_critical;
+  QString val_performance, val_throttle;
+  int 	  val_brightness;
   QString runcommand_val, sound_val;
-  int     low_val;
+  int     low_val_time, low_val_percent, critical_val_time, critical_val_percent;
   int     have_time, type;
-
 };
 
 #endif
