@@ -12,13 +12,12 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #include "util.h"
 #include <kiconloader.h>
-#include <kglobal.h>
 #include <kstandarddirs.h>
 QPixmap Util::getKRegExpEditorIcon( const QString& name )
 {
@@ -44,3 +43,16 @@ QPixmap Util::getSystemIcon( const QString& name )
 #endif
 
 }
+
+QIconSet Util::getSystemIconSet( const QString& name )
+{
+#ifdef QT_ONLY
+    QPixmap pix;
+    pix.convertFromImage( qembed_findImage( name ) );
+    return QIconSet( pix );
+#else
+  KIconLoader loader;
+  return loader.loadIconSet( name, KIcon::Toolbar);
+#endif
+
+}
