@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "chart.h"
@@ -204,28 +204,8 @@ KSim::Chart::LabelType KSim::Chart::labelType() const
   return d->labelType;
 }
 
-void KSim::Chart::configureObject(bool repaintWidget)
+void KSim::Chart::buildPixmaps()
 {
-  QSize oldSize = sizeHint();
-  KSim::Config::config()->setGroup("Misc");
-  d->size = KSim::Config::config()->readSizeEntry("GraphSize");
-
-  if (d->krell && d->showKrell) {
-    int krellHeight = d->krell->fontMetrics().height() - 2;
-    d->size.setHeight(d->size.height() + krellHeight);
-    d->krell->setFixedSize(d->size.width(), krellHeight);
-    d->krell->move(0, d->size.height() - krellHeight);
-    d->krell->show();
-  }
-
-  // Update our geometry if we need to let any
-  // layout know about our sizeHint() change
-  if (oldSize != sizeHint()) {
-    // Using resize() here seems to be needed
-    resize(sizeHint());
-    updateGeometry();
-  }
-
   QImage image(themeLoader().current().chartPixmap());
   KSim::ThemeLoader::self().reColourImage(image);
   d->chartPixmap.convertFromImage(image.smoothScale(chartSize()));
@@ -235,7 +215,7 @@ void KSim::Chart::configureObject(bool repaintWidget)
   image.reset();
   image.load(themeLoader().current().gridPixmap());
   KSim::ThemeLoader::self().reColourImage(image);
-  d->gridPixmap.convertFromImage(image.smoothScale(d->size.width(), 1));
+  d->gridPixmap.convertFromImage(image.smoothScale(chartSize().width(), 1));
 
   // load these values here so we dont need to keep accessing them while
   // painting to keep the cpu usage down
@@ -267,12 +247,34 @@ void KSim::Chart::configureObject(bool repaintWidget)
     kdDebug(2003) << className() << ": Using chartOutColor() = "
        << d->dataOutColour.name() << endl;
   }
+}
+
+void KSim::Chart::configureObject(bool repaintWidget)
+{
+  QSize oldSize = sizeHint();
+  KSim::Config::config()->setGroup("Misc");
+  d->size = KSim::Config::config()->readSizeEntry("GraphSize");
+
+  if (d->krell && d->showKrell) {
+    int krellHeight = d->krell->fontMetrics().height() - 2;
+    d->size.setHeight(d->size.height() + krellHeight);
+    d->krell->setFixedHeight(krellHeight);
+    d->krell->move(0, d->size.height() - krellHeight);
+    d->krell->show();
+  }
+
+  // Update our geometry if we need to let any
+  // layout know about our sizeHint() change
+  if (oldSize != sizeHint()) {
+    // Using resize() here seems to be needed
+    resize(sizeHint());
+    updateGeometry();
+  }
+
+  buildPixmaps();
 
   setConfigValues();
 
-  // Draw our first chart image to make sure it
-  // gets drawn in the correct theme
-  drawChart();
   if (repaintWidget)
     update();
 }
@@ -287,6 +289,13 @@ QSize KSim::Chart::minimumSizeHint() const
   return sizeHint();
 }
 
+void KSim::Chart::resizeEvent(QResizeEvent *re)
+{
+  if (d->chartPixmap.size() != chartSize())
+    buildPixmaps();
+  QWidget::resizeEvent(re);
+}
+
 void KSim::Chart::disableAutomaticUpdates()
 {
     KSim::Chart::Timer::disconnect(this);
@@ -599,7 +608,7 @@ void KSim::Chart::init(bool krell, int maxValue, const QString &title)
 {
   setConfigString("StyleChart");
   setThemeConfigOnly(false);
-  setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
+  setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed));
 
   d = new Private;
   KSim::Config::config()->setGroup("Misc");
@@ -614,5 +623,5 @@ void KSim::Chart::init(bool krell, int maxValue, const QString &title)
   setBackgroundMode(NoBackground);
   setLabelType(Label);
   setMaxValue(maxValue);
-  configureObject();
+  configureObject(false);
 }
